# -*- coding:utf-8 -*-
# 
# Defines Parser class. parse content
# from input file
#
# Author: Kevin Hu

class Parser():
    """
    Escape input file and parse unicode
    """
    def __init__():
        
        pass


    
