# -*- coding:utf-8 -*-
# 
#
# Author: Kevin Hu


TOTALSIZE = 4194304

SUFFIX = {"txt": "text",
         "sh":"bash",
         "asp": "asp", 
         "aspx": "asp",
         "sh": "bash",
         "bat": "bat",
         "c": "c", 
         "h": "c",
         "cs": "csharp",
         "cl": "common-lisp",
         "clj": "clojure",
         "cpp": "cpp",
         "s": "nasm",
         "cpp": "cpp", 
         "cc": "cpp",
         "css": "css", 
         "less": "css",
         "d": "d",
         "erl": "erlang",
         "el": "elisp",
         "f90": "fortran",
         "go": "go",
         "hs": "haskell",
         "html": "html", 
         "htm": "html",
         "ll": "llvm",
         "lua": "lua",
         "java": "java",
         "js": "javascript",
         "m": "objective-c",
         "ocaml": "ocaml",
         "py": "python",
         "pl": "perl",
         "ps": "postscript",
         "pro": "prolog",
         "rb": "ruby",
         "rst": "rst",
         "sch": "scheme",
         "sql": "sql",
         "sass": "css", 
         "scala": "scala",
         "scss": "scss",
         "tcl": "tcl",
         "tex": "tex",
         "v": "verilog",
         "xml": "xml",
         "xslt": "xslt",
         "yml": "yaml",
         "yaml": "yaml"}
